Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(654)

Unified Diff: chrome/test/pyautolib/pyauto.py

Issue 10827050: Added a timezone policy and pyauto tests for it. (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Addressed comments. Created 8 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/test/functional/policy_test_cases.py ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/test/pyautolib/pyauto.py
diff --git a/chrome/test/pyautolib/pyauto.py b/chrome/test/pyautolib/pyauto.py
index 7ef8b953fed768b0f43e23ae388d4e24c10b4f56..1d8ed46387a84c357089357d55607febeba7d202 100755
--- a/chrome/test/pyautolib/pyauto.py
+++ b/chrome/test/pyautolib/pyauto.py
@@ -5713,11 +5713,12 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
"""Sets the timezone on ChromeOS. A user must be logged in.
The timezone is the relative path to the timezone file in
- /usr/share/zoneinfo. For example, /usr/share/zoneinfo/America/Los_Angeles
- is 'America/Los_Angeles'.
+ /usr/share/zoneinfo. For example, /usr/share/zoneinfo/America/Los_Angeles is
+ 'America/Los_Angeles'. For a list of valid timezones see
+ 'chrome/browser/chromeos/system/timezone_settings.cc'.
This method does not return indication of success or failure.
If the timezone is invalid, it falls back to UTC/GMT.
Raises:
pyauto_errors.JSONInterfaceError if the automation call returns an error.
« no previous file with comments | « chrome/test/functional/policy_test_cases.py ('k') | no next file » | no next file with comments »
@@ -5713,11 +5713,12 @@ class PyUITest(pyautolib.PyUITestBase, unittest.TestCase):
This method does not return indication of success or failure.
- If the timezone is invalid, it falls back to UTC/GMT.
+ If the timezone is it falls back to a valid timezone.
Raises:
pyauto_errors.JSONInterfaceError if the automation call returns an error.

Powered by Google App Engine
This is Rietveld 408576698